@@ -390,10 +390,17 @@ class FeedsWindow(hildon.StackableWindow):
 
         # Load Feeds (could be none)
         try:
+            hildon.hildon_gtk_window_set_progress_indicator(self, True)
+            self._load_tag = glib.timeout_add(1000, self._show_loading_banner)
             self.manager.load(self._feed_data_loaded)
         except IOError:
+            hildon.hildon_gtk_window_set_progress_indicator(self, False)
             self._show_initial_dialog()
 
+    def _show_loading_banner(self):
+            hildon.hildon_banner_show_information(self, '', _('Loading feed data'))
+            return False
+
     def _on_connection_changed(self, conn_manager):
         if self._conn_manager.is_online():
             self._new_feed_button.show()
@@ -650,6 +657,9 @@ class FeedsWindow(hildon.StackableWindow):
         # restore normal mode
         self._restore_normal_mode(button)
 
+        # Save data
+        self.manager.save()
+
     def _restore_normal_mode(self, button):
 
         # tree view normal mode
@@ -922,6 +932,9 @@ class FeedsWindow(hildon.StackableWindow):
         dialog.show()
 
     def _feed_data_loaded(self, retval, user_data, error):
+        glib.source_remove(self._load_tag)
+        hildon.hildon_gtk_window_set_progress_indicator(self, False)
+
         # TODO: migrate to "with" statement when available
         try:
             feed_data_list = self.manager.get_feed_list()
@@ -1360,6 +1373,9 @@ class EntriesWindow(hildon.StackableWindow):
         self._update_feed_button.set_sensitive(True)
 
     def _sync_google_reader_read_status_cb(self, synced, user_data, error):
+        hildon.hildon_gtk_window_set_progress_indicator(self, False)
+        self._update_feed_button.set_sensitive(True)
+
         if not synced:
             hildon.hildon_banner_show_information(self, '', _('Error syncing read status with Google Reader'))
             return
@@ -1367,9 +1383,6 @@ class EntriesWindow(hildon.StackableWindow):
         self.view.get_model().get_model().clear()
         self._add_entries()
 
-        hildon.hildon_gtk_window_set_progress_indicator(self, False)
-        self._update_feed_button.set_sensitive(True)
-
     def _mark_read_cb(self, button, read):
         # tree view edit mode
         hildon.hildon_gtk_tree_view_set_ui_mode(self.view, gtk.HILDON_UI_MODE_EDIT)
