@@ -45,6 +45,7 @@ class Settings(object):
         self.user  = ''
         self.password = ''
         self.sync_global = False
+        self.entries_filter = constants.SHOW_ALL_FILTER
 
     def load(self):
         if not (os.path.exists(constants.RSS_CONF_FILE) and
@@ -66,6 +67,7 @@ class Settings(object):
         self.user = self.config['user'] if 'user' in self.config else ''
         self.password = self.config['password'] if 'password' in self.config else ''
         self.sync_global = self.config['sync_global'] if 'sync_global' in self.config else False
+        self.entries_filter = self.config['entries_filter'] if 'entries_filter' in self.config else constants.SHOW_ALL_FILTER
 
     def save(self):
         if self.config == None:
@@ -81,5 +83,6 @@ class Settings(object):
         self.config['user'] = self.user
         self.config['password'] = self.password
         self.config['sync_global'] = self.sync_global
+        self.config['entries_filter'] = self.entries_filter
 
         self.config.write()
